==> luna_lambda_tools-0.0.56.tar.gz: luna_lambda_tools-0.0.56/luna_lambda_tools/private/base_application.py <==
import asyncio
from typing import Awaitable

from cow.utils import mixins
from cow.utils.check_connection import (
    checkConnectionToLunaEvents,
    checkConnectionToLunaFaces,
    checkConnectionToLunaImageStore,
    checkConnectionToLunaPythonMatcher,
    checkConnectionToLunaRemoteSDK,
    checkConnectionToLunaSender,
    checkConnectionToLunaVideoAgent,
)
from cow.utils.healthcheck import checkService
from cow.web.application import LunaApp
from cow.web.base_proxy_handler_class import SessionPool
from cow.web.context import LunaAppCtx
from cow.web.request import VLRequest
from luna3.client import Luna3Session as BaseLuna3Session
from luna3.common.base_api import BaseHTTPAPI
from luna3.settings import HTTPSettings
from luna_plugins.base.manager import PluginManager
from sanic import HTTPResponse

from .config import DEFAULT_PORT
from .configs.configs.services import SettingsLambdaUnit
from .configs.configs.settings.classes import ServiceAddressSettings, ServiceTimeoutsSettings
from .monitoring import MonitoringPoint


class FakeManager:
    """Fake plugin manager"""

    @classmethod
    async def shutdown(cls):
        """Prevent default luna-application behaviour"""

    @staticmethod
    def sendEventToPlugins(*args, **kwargs):
        """Prevent default luna-application behaviour"""


class Luna3Session(BaseLuna3Session, mixins.Initializable):
    """
    Initializable luna3 sessions.

    Attributes:
        settings (SettingsApi): service settings (need for check connections)
    """

    def __init__(self, settings: SettingsLambdaUnit, lambdaType: str):
        self.settings = settings
        super().__init__(**self._getLuna3Kwargs())
        self.lambdaType = lambdaType

    def getRuntimeChecks(self, includeLunaServices: bool = False) -> list[tuple[str, Awaitable]]:
        """
        Returns configured system checks, pairs of (name, coroutine).

        Warnings:
            Check license session in licenseChecker

        Args:
            includeLunaServices: A bool, whether to include checks for luna services.
        """
        checks = []

        if not includeLunaServices or self.lambdaType == "standalone":
            return checks

        if self.facesSession:
            facesClient = self.facesSession.getClient()
            checks.append(("faces", checkService(facesClient, includeLunaServices)))
        if self.pythonMatcherSession:
            matcherClient = self.pythonMatcherSession.getClient()
            checks.append(("matcher", checkService(matcherClient, includeLunaServices)))
        if self.remoteSDKSession:
            remoteSDKClient = self.remoteSDKSession.getClient()
            checks.append(("remote_sdk", checkService(remoteSDKClient, includeLunaServices)))
        if self.videoAgentSession:
            videoAgentClient = self.videoAgentSession.getClient()
            checks.append(("video_agent", checkService(videoAgentClient, includeLunaServices)))
        if self.faceSampleStoreSession:
            faceSamplesClient = self.faceSampleStoreSession.getClient()
            checks.append(("face_samples", checkService(faceSamplesClient, includeLunaServices)))
        if self.bodySampleStoreSession:
            bodySamplesClient = self.bodySampleStoreSession.getClient()
            checks.append(("body_samples", checkService(bodySamplesClient, includeLunaServices)))
        if self.imageOriginStoreSession:
            imageOriginClient = self.imageOriginStoreSession.getClient()
            checks.append(("image_origin_store", checkService(imageOriginClient, includeLunaServices)))
        if self.senderSession:
            senderClient = self.senderSession.getClient()
            checks.append(("sender", checkService(senderClient, includeLunaServices)))
        if self.eventSession:
            eventsClient = self.eventSession.getClient()
            checks.append(("events", checkService(eventsClient, includeLunaServices)))
        return checks

    def getProbeChecks(self):
        """Get checks for probe"""
        checks = []
        if self.lambdaType == "standalone":
            return []

        def generateCheck(client: BaseHTTPAPI, checker, postfix: str = "", **kwargs):
            check = checker(
                client.origin,
                client.api,
                totalTimeout=client.totalTimeout,
                connectTimeout=client.connectTimeout,
                sockReadTimeout=client.sockReadTimeout,
                sockConnectTimeout=client.sockConnectTimeout,
                asyncCheck=True,
                postfix=postfix,
                **kwargs,
            )

            return check

        if self.facesSession:
            facesClient = self.facesSession.getClient()
            checks.append(generateCheck(facesClient, checkConnectionToLunaFaces))
        if self.pythonMatcherSession:
            matcherClient = self.pythonMatcherSession.getClient()
            checks.append(generateCheck(matcherClient, checkConnectionToLunaPythonMatcher))
        if self.remoteSDKSession:
            remoteSDKClient = self.remoteSDKSession.getClient()
            checks.append(generateCheck(remoteSDKClient, checkConnectionToLunaRemoteSDK))
        if self.videoAgentSession:
            videoAgentClient = self.videoAgentSession.getClient()
            checks.append(generateCheck(videoAgentClient, checkConnectionToLunaVideoAgent))
        if self.faceSampleStoreSession:
            faceSamplesClient = self.faceSampleStoreSession.getClient()
            checks.append(
                generateCheck(
                    faceSamplesClient,
                    checkConnectionToLunaImageStore,
                    postfix="faces_samples",
                    bucket=self.settings.faceSamplesStorage.bucket,
                )
            )
        if self.bodySampleStoreSession:
            bodySamplesClient = self.bodySampleStoreSession.getClient()
            checks.append(
                generateCheck(
                    bodySamplesClient,
                    checkConnectionToLunaImageStore,
                    postfix="bodies_samples",
                    bucket=self.settings.bodySamplesStorage.bucket,
                )
            )

        if self.imageOriginStoreSession:
            imageOriginClient = self.imageOriginStoreSession.getClient()
            checks.append(
                generateCheck(
                    imageOriginClient,
                    checkConnectionToLunaImageStore,
                    postfix="images",
                    bucket=self.settings.imageOriginStorage.bucket,
                )
            )
        if self.senderSession:
            senderClient = self.senderSession.getClient()
            checks.append(generateCheck(senderClient, checkConnectionToLunaSender))
        if self.eventSession:
            eventsClient = self.eventSession.getClient()
            checks.append(generateCheck(eventsClient, checkConnectionToLunaEvents))
        return checks

    async def probe(self) -> bool:
        """Check that we can connect to the services with current configuration. Can be used without initialization"""
        return all(await asyncio.gather(*self.getProbeChecks()))

    def _getLuna3Kwargs(self) -> dict[str, HTTPSettings]:
        """
        Get kwargs for initialization luna3 sessions

        Returns:
            kwargs for Luna3Session
        """
        kwargs = {
            "facesSettings": HTTPSettings(
                self.settings.facesAddress.apiVersion,
                self.settings.facesAddress.origin,
                **self.settings.facesTimeouts.asDict(),
                asyncRequest=True,
            ),
            "remoteSDKSettings": HTTPSettings(
                self.settings.remoteSDKAddress.apiVersion,
                self.settings.remoteSDKAddress.origin,
                asyncRequest=True,
            ),
        }
        if self.settings.additionalServicesUsage.lunaImageStore:
            kwargs.update(
                {
                    "faceSampleStoreSettings": HTTPSettings(
                        self.settings.faceSamplesStorage.apiVersion,
                        self.settings.faceSamplesStorage.origin,
                        **self.settings.faceSamplesStorageTimeouts.asDict(),
                        asyncRequest=True,
                    ),
                    "bodySampleStoreSettings": HTTPSettings(
                        self.settings.bodySamplesStorage.apiVersion,
                        self.settings.bodySamplesStorage.origin,
                        **self.settings.bodySamplesStorageTimeouts.asDict(),
                        asyncRequest=True,
                    ),
                    "imageOriginStoreSettings": HTTPSettings(
                        self.settings.imageOriginStorage.apiVersion,
                        self.settings.imageOriginStorage.origin,
                        **self.settings.imageOriginStorageTimeouts.asDict(),
                        asyncRequest=True,
                    ),
                }
            )

        if self.settings.additionalServicesUsage.lunaMatcherProxy:
            kwargs["pythonMatcherSettings"] = HTTPSettings(
                self.settings.matcherProxyAddress.apiVersion,
                self.settings.matcherProxyAddress.origin,
                **self.settings.matcherProxyTimeouts.asDict(),
                asyncRequest=True,
            )
        else:
            kwargs["pythonMatcherSettings"] = HTTPSettings(
                self.settings.pythonMatcherAddress.apiVersion,
                self.settings.pythonMatcherAddress.origin,
                **self.settings.pythonMatcherTimeouts.asDict(),
                asyncRequest=True,
            )
        if self.settings.additionalServicesUsage.lunaEvents:
            kwargs["eventSettings"] = HTTPSettings(
                self.settings.eventsAddress.apiVersion,
                self.settings.eventsAddress.origin,
                **self.settings.eventsTimeouts.asDict(),
                asyncRequest=True,
            )
        if self.settings.additionalServicesUsage.lunaSender:
            kwargs["senderSettings"] = HTTPSettings(
                self.settings.senderAddress.apiVersion,
                self.settings.senderAddress.origin,
                asyncRequest=True,
            )
        if self.settings.additionalServicesUsage.lunaVideoAgent:
            kwargs["videoAgentSettings"] = HTTPSettings(
                self.settings.videoAgentAddress.apiVersion,
                self.settings.videoAgentAddress.origin,
                asyncRequest=True,
            )
        return kwargs


class BaseAppCtx[TConfig: SettingsLambdaUnit](LunaAppCtx):
    """Configurator application context"""

    lambdaVersion: int
    userCtx: object | None = None
    lambdaName: str | None
    lambdaType: str | None

    def __init__(self, *args, **kwargs):
        preparedArgs = [arg for arg in args if not isinstance(arg, PluginManager)]
        super().__init__(pluginManager=FakeManager(), *preparedArgs, **kwargs)
        try:
            from lambda_main import UserCtx

            self.userCtx = UserCtx()
        except ImportError:
            self.userCtx = None

    async def initialize(self):
        """Description see :func:`~_LunaApplication.initialize`"""
        self.serviceConfig.activePlugins = []
        await super().initialize()
        if hasattr(self.userCtx, "onStart"):
            return await self.userCtx.onStart()
        MonitoringPoint.initialize(serviceName=self.lambdaName)
        await SessionPool.initialize()

    async def shutdown(self):
        await super().close()
        if hasattr(self.userCtx, "onShutdown"):
            return await self.userCtx.onShutdown()
        await SessionPool.close()


def getServiceClientKwargs(addressSetting: ServiceAddressSettings, timeoutSettings: ServiceTimeoutsSettings) -> dict:
    """Get service client kwargs"""
    return {
        "origin": addressSetting.origin,
        "api": addressSetting.apiVersion,
        "totalTimeout": timeoutSettings.totalTimeout,
        "connectTimeout": timeoutSettings.connectTimeout,
        "sockConnectTimeout": timeoutSettings.sockConnectTimeout,
        "sockReadTimeout": timeoutSettings.sockReadTimeout,
        "asyncRequest": True,
    }


async def lambdaVersionMiddleware(request: VLRequest, response: HTTPResponse):
    """
    Monitoring middleware. Generate a request point and error point and send them to app monitoring.

    Args:
        request: request
        response: response
    """
    response.headers["Lambda-Version"] = request.app.ctx.lambdaVersion


class BaseLambdaApp[TConfig: SettingsLambdaUnit, TCtx: BaseAppCtx](LunaApp):
    """
    Base lambda application
    """

    # service api version
    apiVersion: int = 1
    # lambda default port
    defaultPort = DEFAULT_PORT

    def setUpSanic(self):
        """setup web framework"""
        super().setUpSanic()
        self.sanic.register_middleware(lambdaVersionMiddleware, "response")

==> luna_lambda_tools-0.0.71.tar.gz: luna_lambda_tools-0.0.71/luna_lambda_tools/private/base_application.py <==
import asyncio
from typing import Awaitable

from cow.utils import mixins
from cow.utils.check_connection import (
    checkConnectionToLunaEvents,
    checkConnectionToLunaFaces,
    checkConnectionToLunaImageStore,
    checkConnectionToLunaPythonMatcher,
    checkConnectionToLunaRemoteSDK,
    checkConnectionToLunaSender,
    checkConnectionToLunaVideoAgent,
)
from cow.utils.healthcheck import checkService
from cow.web.application import LunaApp
from cow.web.base_proxy_handler_class import SessionPool
from cow.web.context import LunaAppCtx
from cow.web.request import VLRequest
from luna3.client import Luna3Session as BaseLuna3Session
from luna3.common.base_api import BaseHTTPAPI
from luna3.settings import HTTPSettings
from luna_plugins.base.manager import PluginManager
from sanic import HTTPResponse

from .config import DEFAULT_PORT
from .configs.configs.settings.classes import ServiceAddressSettings, ServiceTimeoutsSettings
from .monitoring import MonitoringPoint
from .unit_config import ServiceSettings


class FakeManager:
    """Fake plugin manager"""

    @classmethod
    async def shutdown(cls):
        """Prevent default luna-application behaviour"""

    @staticmethod
    def sendEventToPlugins(*args, **kwargs):
        """Prevent default luna-application behaviour"""


class Luna3Session(BaseLuna3Session, mixins.Initializable):
    """
    Initializable luna3 sessions.

    Attributes:
        settings (SettingsApi): service settings (need for check connections)
    """

    def __init__(self, settings: ServiceSettings, lambdaType: str):
        self.settings = settings
        super().__init__(**self._getLuna3Kwargs())
        self.lambdaType = lambdaType

    def getRuntimeChecks(self, includeLunaServices: bool = False) -> list[tuple[str, Awaitable]]:
        """
        Returns configured system checks, pairs of (name, coroutine).

        Warnings:
            Check license session in licenseChecker

        Args:
            includeLunaServices: A bool, whether to include checks for luna services.
        """
        checks = []

        if not includeLunaServices or self.lambdaType == "standalone":
            return checks

        if self.facesSession:
            facesClient = self.facesSession.getClient()
            checks.append(("faces", checkService(facesClient, includeLunaServices)))
        if self.pythonMatcherSession:
            matcherClient = self.pythonMatcherSession.getClient()
            checks.append(("matcher", checkService(matcherClient, includeLunaServices)))
        if self.remoteSDKSession:
            remoteSDKClient = self.remoteSDKSession.getClient()
            checks.append(("remote_sdk", checkService(remoteSDKClient, includeLunaServices)))
        if self.videoAgentSession:
            videoAgentClient = self.videoAgentSession.getClient()
            checks.append(("video_agent", checkService(videoAgentClient, includeLunaServices)))
        if self.faceSampleStoreSession:
            faceSamplesClient = self.faceSampleStoreSession.getClient()
            checks.append(("face_samples", checkService(faceSamplesClient, includeLunaServices)))
        if self.bodySampleStoreSession:
            bodySamplesClient = self.bodySampleStoreSession.getClient()
            checks.append(("body_samples", checkService(bodySamplesClient, includeLunaServices)))
        if self.imageOriginStoreSession:
            imageOriginClient = self.imageOriginStoreSession.getClient()
            checks.append(("image_origin_store", checkService(imageOriginClient, includeLunaServices)))
        if self.senderSession:
            senderClient = self.senderSession.getClient()
            checks.append(("sender", checkService(senderClient, includeLunaServices)))
        if self.eventSession:
            eventsClient = self.eventSession.getClient()
            checks.append(("events", checkService(eventsClient, includeLunaServices)))
        return checks

    def getProbeChecks(self):
        """Get checks for probe"""
        checks = []
        if self.lambdaType == "standalone":
            return []

        def generateCheck(client: BaseHTTPAPI, checker, postfix: str = "", **kwargs):
            check = checker(
                client.origin,
                client.api,
                totalTimeout=client.totalTimeout,
                connectTimeout=client.connectTimeout,
                sockReadTimeout=client.sockReadTimeout,
                sockConnectTimeout=client.sockConnectTimeout,
                asyncCheck=True,
                postfix=postfix,
                **kwargs,
            )

            return check

        if self.facesSession:
            facesClient = self.facesSession.getClient()
            checks.append(generateCheck(facesClient, checkConnectionToLunaFaces))
        if self.pythonMatcherSession:
            matcherClient = self.pythonMatcherSession.getClient()
            checks.append(generateCheck(matcherClient, checkConnectionToLunaPythonMatcher))
        if self.remoteSDKSession:
            remoteSDKClient = self.remoteSDKSession.getClient()
            checks.append(generateCheck(remoteSDKClient, checkConnectionToLunaRemoteSDK))
        if self.videoAgentSession:
            videoAgentClient = self.videoAgentSession.getClient()
            checks.append(generateCheck(videoAgentClient, checkConnectionToLunaVideoAgent))
        if self.faceSampleStoreSession:
            faceSamplesClient = self.faceSampleStoreSession.getClient()
            checks.append(
                generateCheck(
                    faceSamplesClient,
                    checkConnectionToLunaImageStore,
                    postfix="faces_samples",
                    bucket=self.settings.faceSamplesStorage.bucket,
                )
            )
        if self.bodySampleStoreSession:
            bodySamplesClient = self.bodySampleStoreSession.getClient()
            checks.append(
                generateCheck(
                    bodySamplesClient,
                    checkConnectionToLunaImageStore,
                    postfix="bodies_samples",
                    bucket=self.settings.bodySamplesStorage.bucket,
                )
            )

        if self.imageOriginStoreSession:
            imageOriginClient = self.imageOriginStoreSession.getClient()
            checks.append(
                generateCheck(
                    imageOriginClient,
                    checkConnectionToLunaImageStore,
                    postfix="images",
                    bucket=self.settings.imageOriginStorage.bucket,
                )
            )
        if self.senderSession:
            senderClient = self.senderSession.getClient()
            checks.append(generateCheck(senderClient, checkConnectionToLunaSender))
        if self.eventSession:
            eventsClient = self.eventSession.getClient()
            checks.append(generateCheck(eventsClient, checkConnectionToLunaEvents))
        return checks

    async def probe(self) -> bool:
        """Check that we can connect to the services with current configuration. Can be used without initialization"""
        return all(await asyncio.gather(*self.getProbeChecks()))

    def _getLuna3Kwargs(self) -> dict[str, HTTPSettings]:
        """
        Get kwargs for initialization luna3 sessions

        Returns:
            kwargs for Luna3Session
        """
        kwargs = {
            "facesSettings": HTTPSettings(
                self.settings.facesAddress.apiVersion,
                self.settings.facesAddress.origin,
                **self.settings.facesTimeouts.asDict(),
                asyncRequest=True,
            ),
            "remoteSDKSettings": HTTPSettings(
                self.settings.remoteSDKAddress.apiVersion,
                self.settings.remoteSDKAddress.origin,
                asyncRequest=True,
            ),
        }
        if self.settings.additionalServicesUsage.lunaImageStore:
            kwargs.update(
                {
                    "faceSampleStoreSettings": HTTPSettings(
                        self.settings.faceSamplesStorage.apiVersion,
                        self.settings.faceSamplesStorage.origin,
                        **self.settings.faceSamplesStorageTimeouts.asDict(),
                        asyncRequest=True,
                    ),
                    "bodySampleStoreSettings": HTTPSettings(
                        self.settings.bodySamplesStorage.apiVersion,
                        self.settings.bodySamplesStorage.origin,
                        **self.settings.bodySamplesStorageTimeouts.asDict(),
                        asyncRequest=True,
                    ),
                    "imageOriginStoreSettings": HTTPSettings(
                        self.settings.imageOriginStorage.apiVersion,
                        self.settings.imageOriginStorage.origin,
                        **self.settings.imageOriginStorageTimeouts.asDict(),
                        asyncRequest=True,
                    ),
                }
            )

        if self.settings.additionalServicesUsage.lunaMatcherProxy:
            kwargs["pythonMatcherSettings"] = HTTPSettings(
                self.settings.matcherProxyAddress.apiVersion,
                self.settings.matcherProxyAddress.origin,
                **self.settings.matcherProxyTimeouts.asDict(),
                asyncRequest=True,
            )
        else:
            kwargs["pythonMatcherSettings"] = HTTPSettings(
                self.settings.pythonMatcherAddress.apiVersion,
                self.settings.pythonMatcherAddress.origin,
                **self.settings.pythonMatcherTimeouts.asDict(),
                asyncRequest=True,
            )
        if self.settings.additionalServicesUsage.lunaEvents:
            kwargs["eventSettings"] = HTTPSettings(
                self.settings.eventsAddress.apiVersion,
                self.settings.eventsAddress.origin,
                **self.settings.eventsTimeouts.asDict(),
                asyncRequest=True,
            )
        if self.settings.additionalServicesUsage.lunaSender:
            kwargs["senderSettings"] = HTTPSettings(
                self.settings.senderAddress.apiVersion,
                self.settings.senderAddress.origin,
                asyncRequest=True,
            )
        if self.settings.additionalServicesUsage.lunaVideoAgent:
            kwargs["videoAgentSettings"] = HTTPSettings(
                self.settings.videoAgentAddress.apiVersion,
                self.settings.videoAgentAddress.origin,
                asyncRequest=True,
            )
        return kwargs


class BaseAppCtx[TConfig: ServiceSettings](LunaAppCtx):
    """Configurator application context"""

    lambdaVersion: int
    userCtx: object | None = None
    lambdaName: str | None
    lambdaType: str | None

    def __init__(self, *args, **kwargs):
        preparedArgs = [arg for arg in args if not isinstance(arg, PluginManager)]
        super().__init__(pluginManager=FakeManager(), *preparedArgs, **kwargs)
        try:
            from lambda_main import UserCtx

            self.userCtx = UserCtx()
        except ImportError:
            self.userCtx = None

    async def initialize(self):
        """Description see :func:`~_LunaApplication.initialize`"""
        self.serviceConfig.activePlugins = []
        await super().initialize()
        if hasattr(self.userCtx, "onStart"):
            return await self.userCtx.onStart()
        MonitoringPoint.initialize(serviceName=self.lambdaName)
        await SessionPool.initialize()

    async def shutdown(self):
        await super().close()
        if hasattr(self.userCtx, "onShutdown"):
            return await self.userCtx.onShutdown()
        await SessionPool.close()


def getServiceClientKwargs(addressSetting: ServiceAddressSettings, timeoutSettings: ServiceTimeoutsSettings) -> dict:
    """Get service client kwargs"""
    return {
        "origin": addressSetting.origin,
        "api": addressSetting.apiVersion,
        "totalTimeout": timeoutSettings.totalTimeout,
        "connectTimeout": timeoutSettings.connectTimeout,
        "sockConnectTimeout": timeoutSettings.sockConnectTimeout,
        "sockReadTimeout": timeoutSettings.sockReadTimeout,
        "asyncRequest": True,
    }


async def lambdaVersionMiddleware(request: VLRequest, response: HTTPResponse):
    """
    Monitoring middleware. Generate a request point and error point and send them to app monitoring.

    Args:
        request: request
        response: response
    """
    response.headers["Lambda-Version"] = request.app.ctx.lambdaVersion


class BaseLambdaApp[TConfig: ServiceSettings, TCtx: BaseAppCtx](LunaApp):
    """
    Base lambda application
    """

    # service api version
    apiVersion: int = 1
    # lambda default port
    defaultPort = DEFAULT_PORT

    def setUpSanic(self):
        """setup web framework"""
        super().setUpSanic()
        self.sanic.register_middleware(lambdaVersionMiddleware, "response")
